interest.description.format

# XMLRésuméLibrary: User Guide

header.format | XSL Parameter Reference | referees.display

## Name

interest.description.format — controls formatting of interest descriptions

## Applies To

This parameter controls the formatting of the `description` element when it is contained in an `interest`. It affects all output formats.

## Possible Values

Possible values include `single-line` and `block`. `single-line` is the default.

The examples below demonstrate the formatting of this XML fragment:

    <interests>
      <interest>
        <title>Scuba diving</title>
      </interest>
      <interest>
        <title>Flying</title>
        <description>
          <para>I have my pilot's license, and have logged over 1000 in-flight
          hours.</para>
          <para>I have also constructed my own airplane from a kit.</para>
        </description>
      </interest>
    </interests>

`single-line`

  This value is the default. Formats all of the `para` elements in the description on the same logical line as the interest title. The title is separated from the description by a period, and the description paragraphs are separated from each other by `description.para.separator.text`, which defaults to an em-dash (“—”).

  For example, the XML above would be formatted similar to the following:

  ### Interests

  - Scuba diving

  - Flying. I have my pilot's license, and have logged over 1000 in-flight hours. — I have also constructed my own airplane from a kit.

`block`

  Formats each of the `para` elements in the description as a separate block below the interest title.

  For example, the XML above would be formatted similar to the following:

  ### Interests

  - Scuba diving

  - Flying

    I have my pilot's license, and have logged over 1000 in-flight hours.

    I have also constructed my own airplane from a kit.

header.format | XSL Parameter Reference | referees.display